richtexteditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# richtexteditor

class `camelot.view.controls.editors.richtexteditor.` `CustomTextEdit`(parent)

  A TextEdit editor that sends editingFinished events when the text was changed and focus is lost.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus